@@ -5,6 +5,8 @@ cd build
 cmake -DCMAKE_INSTALL_PREFIX=$PREFIX \
       -DCMAKE_PREFIX_PATH=$PREFIX \
       -DCMAKE_INSTALL_LIBDIR=lib \
+      -DENABLE_CONDA=ON \
+      -DMULTI_SEMANTICS=ON \
       ..
 
 make VERBOSE=1 -j${CPU_COUNT}
